Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/irorun/__init__.py | (no class) | 0 | 0 | 0 | 100%
src/irorun/cli.py | (no class) | 108 | 61 | 0 | 44%
src/irorun/helpers.py | EnvManager | 0 | 0 | 0 | 100%
src/irorun/helpers.py | (no class) | 65 | 0 | 0 | 100%
src/irorun/logger_setup.py | TyperLoggerHandler | 16 | 6 | 0 | 62%
src/irorun/logger_setup.py | (no class) | 16 | 5 | 0 | 69%
Total |  | 205 | 72 | 0 | 65%

No items found using the specified filter.